@@ -53,8 +53,6 @@
 
 using namespace ost;
 
-extern bool _dtmf;
-
 bool AudioFile::afCreate(const char *name, bool exclusive)
 {
 	AudioFile::close();
@@ -200,12 +198,12 @@ void AudioFile::afClose(void)
 
 void AudioFile::initialize(void)
 {
-	_dtmf = true;
 	minimum = 0;
 	pathname = NULL;
 	info.annotation = NULL;
 	header = 0l;
 	iolimit = 0l;
+	mode = modeInfo;
 #ifdef	WIN32
 	SETFD(file, INVALID_HANDLE_VALUE);
 #else
